Index: Source/modules/crypto/NormalizeAlgorithm.h |
diff --git a/Source/modules/crypto/NormalizeAlgorithm.h b/Source/modules/crypto/NormalizeAlgorithm.h |
index 93d30db2f60e551d9b3d1dd4ac7a4f9c66abd721..634d4aafd1da981fcccbea9488a3fe654d66e5bd 100644 |
--- a/Source/modules/crypto/NormalizeAlgorithm.h |
+++ b/Source/modules/crypto/NormalizeAlgorithm.h |
@@ -31,8 +31,6 @@ |
#ifndef NormalizeAlgorithm_h |
#define NormalizeAlgorithm_h |
-#include "wtf/Assertions.h" |
- |
namespace WebKit { class WebCryptoAlgorithm; } |
namespace WebCore { |
@@ -55,8 +53,9 @@ enum AlgorithmOperation { |
}; |
// Normalizes an algorithm identifier (dictionary) into a WebCryptoAlgorithm. If |
// normalization fails then returns false and sets |es|. |
bool normalizeAlgorithm(const Dictionary&, AlgorithmOperation, WebKit::WebCryptoAlgorithm&, ExceptionState&) WARN_UNUSED_RETURN; |
+bool normalizeAlgorithmForImportKey(const Dictionary&, WebKit::WebCryptoAlgorithm&, ExceptionState&) WARN_UNUSED_RETURN; |
} // namespace WebCore |
@@ -55,8 +53,9 @@ enum AlgorithmOperation { |
}; |
// Normalizes an algorithm identifier (dictionary) into a WebCryptoAlgorithm. If |
-// normalization fails then returns false and sets |es|. |
+// normalization fails then returns false and sets the ExceptionState. |
bool normalizeAlgorithm(const Dictionary&, AlgorithmOperation, WebKit::WebCryptoAlgorithm&, ExceptionState&) WARN_UNUSED_RETURN; |